pub struct Line2D { /* private fields */ }Expand description
A 2D line defined by origin and direction.
Parameterized as P(t) = origin + t * direction.
Implementations
Sourceimpl Line2D
impl Line2D
Sourcepub fn project(&self, point: Point2) -> f64
pub fn project(&self, point: Point2) -> f64
Projects a point onto the line, returning the closest parameter.
Sourcepub fn distance_to_point(&self, point: Point2) -> f64
pub fn distance_to_point(&self, point: Point2) -> f64
Returns the perpendicular distance from a point to the line.