Module surface_fitting

Module surface_fitting 

NURBS surface fitting from a grid of data points via least-squares progressive-iterative approximation (LSPIA).

Functions

approximate_surface_lspia
Approximate a NURBS surface through a grid of data points using LSPIA.
interpolate_surface
Interpolate a NURBS surface through a grid of data points.