Enums
- Orientation
- Classification of the orientation of three points in the plane.
- Orientation3D
- Classification of a point’s position relative to an oriented plane.
Functions
- in_
circle - Exact in-circle test for four 2D points.
- insphere
- Exact in-sphere test for five 3D points.
- orient2d
- Compute the exact orientation determinant of the triangle (a, b, c).
- orient2d_
sos - Compute
orient2d(a, b, c)with symbolic perturbation to resolve degeneracy. - orient3d
- Compute the exact orientation of point
drelative to the plane through(a, b, c). - orient3d_
sos - Compute
orient3d(a, b, c, d)with symbolic perturbation to resolve degeneracy. - orientation2d
- Classify the orientation of three points in the plane.
- orientation3d
- Classify the orientation of point
drelative to the plane through(a, b, c). - point_
in_ polygon - Test whether a point lies inside a polygon using the winding number rule.
- winding_
number - Compute the winding number of a point with respect to a polygon.