in_circle

Function in_circle 

pub fn in_circle(a: Point2, b: Point2, c: Point2, d: Point2) -> f64
Exact in-circle test for four 2D points.

Returns a positive value if d lies inside the circumcircle of (a, b, c) (when a, b, c are in counter-clockwise order), negative if outside, and zero if on the circle.