pub fn orientation2d(a: Point2, b: Point2, c: Point2) -> OrientationExpand description
Classify the orientation of three points in the plane.
pub fn orientation2d(a: Point2, b: Point2, c: Point2) -> OrientationClassify the orientation of three points in the plane.