Module surfaces

Module surfaces 

Analytic surface types for exact geometric computations.

These surfaces complement NURBS surfaces by providing exact parameterizations for common shapes (cylinder, cone, sphere, torus). This enables exact intersection algorithms (e.g., plane-cylinder = ellipse) without sampling.

Structs

ConicalSurface
An infinite conical surface.
CylindricalSurface
An infinite cylindrical surface.
RevolutionSurface
A surface of revolution created by revolving a curve around an axis.
SphericalSurface
An infinite spherical surface (actually a sphere).
ToroidalSurface
A toroidal surface.