pub fn intersect_plane_cone(
cone: &ConicalSurface,
normal: Vec3,
d: f64,
) -> Result<Vec<IntersectionCurve>, MathError>Expand description
Intersect a plane with a conical surface.
Like a cylinder, the cone is linear along each generatrix, so the plane
equation is linear in v for each fixed u.
Errors
Returns an error if curve fitting fails.