pub fn intersect_plane_sphere(
sphere: &SphericalSurface,
normal: Vec3,
d: f64,
) -> Result<Vec<IntersectionCurve>, MathError>Expand description
Intersect a plane with a spherical surface.
The intersection of a plane with a sphere is a circle (or empty/point). Computes the circle center, radius, and samples points on it.
Errors
Returns an error if curve fitting fails.