NURBS surface fitting from a grid of data points via least-squares progressive-iterative approximation (LSPIA).
Functions
- approximate_
surface_ lspia - Approximate a NURBS surface through a grid of data points using LSPIA.
- interpolate_
surface - Interpolate a NURBS surface through a grid of data points.