orient2d

Function orient2d 

pub fn orient2d(a: Point2, b: Point2, c: Point2) -> f64
Compute the exact orientation determinant of the triangle (a, b, c).

Returns a positive value if the points are counter-clockwise, negative if clockwise, and zero if collinear.